@@ -8,10 +8,12 @@ package Struct::Dumb;
 use strict;
 use warnings;
 
-our $VERSION = '0.06';
+our $VERSION = '0.07';
 
 use Carp;
 
+use Scalar::Util qw( refaddr );
+
 =head1 NAME
 
 C<Struct::Dumb> - make simple lightweight record-like structures
@@ -208,7 +210,10 @@ sub _struct
    require overload;
    $pkg->overload::OVERLOAD(
       '@{}'  => sub { croak "Cannot use $pkg as an ARRAY reference" },
+      '0+'   => sub { refaddr $_[0] },
+      '""'   => sub { sprintf "%s=Struct::Dumb(%#x)", $pkg, refaddr $_[0] },
       'bool' => sub { 1 },
+      fallback => 1,
    );
 }
 
